@@ -56,6 +56,8 @@ class FirewallApp(app_module.App):
 
     app_id = 'firewall'
 
+    can_be_disabled = False
+
     def __init__(self):
         """Create components for the app."""
         super().__init__()
@@ -104,7 +106,7 @@ def force_upgrade(helper, packages):
 
     # firewalld 0.6.x -> 0.7.x, 0.6.x -> 0.8.x, 0.7.x -> 0.8.x
     package = packages['firewalld']
-    if Version(package['current_version']) >= Version('0.8') or \
+    if Version(package['current_version']) >= Version('0.9') or \
        Version(package['new_version']) < Version('0.7'):
         return False
 
@@ -140,6 +142,45 @@ def ignore_dbus_error(dbus_error=None, service_error=None):
             raise
 
 
+def parse_dbus_error(exception):
+    """Parse a GDBus error."""
+    parts = exception.message.split(':')
+    if parts[0] != 'GDBus.Error' or \
+       parts[1] != 'org.fedoraproject.FirewallD1.Exception':
+        return None
+
+    return parts[2].strip()
+
+
+def reload():
+    """Reload firewalld."""
+    logger.info('Reloading firewalld')
+    with ignore_dbus_error(dbus_error='ServiceUnknown'):
+        proxy = _get_dbus_proxy(_FIREWALLD_OBJECT, _FIREWALLD_INTERFACE)
+        proxy.reload()
+
+
+def try_with_reload(operation):
+    """Try an operation and retry after firewalld reload.
+
+    When a service file is newly installed into /usr/lib/firewalld/services,
+    it's information can be immediately queried but the service can't be
+    added/removed from a zone. A firewalld reload is necessary. So, try an
+    operation and if it fails with INVALID_SERVICE error, reload firewalld and
+    try again.
+
+    """
+    try:
+        operation()
+    except glib.Error as exception:
+        error = parse_dbus_error(exception)
+        if error != 'INVALID_SERVICE':
+            raise
+
+        reload()
+        operation()
+
+
 def get_enabled_status():
     """Return whether firewall is enabled"""
     output = _run(['get-status'], superuser=True)
