@@ -23,7 +23,6 @@ class GitwebAppView(views.AppView):
     """Serve configuration page."""
 
     app_id = 'gitweb'
-    show_status_block = False
     template_name = 'gitweb_configure.html'
 
     def get_context_data(self, *args, **kwargs):
@@ -32,6 +31,7 @@ class GitwebAppView(views.AppView):
         repos = gitweb.app.get_repo_list()
         context['repos'] = repos
         context['cloning'] = any('clone_progress' in repo for repo in repos)
+        context['refresh_page_sec'] = 3 if context['cloning'] else None
         return context
 
 
@@ -61,11 +61,15 @@ class CreateRepoView(SuccessMessageMixin, FormView):
         try:
             gitweb.create_repo(form_data['name'], form_data['description'],
                                form_data['owner'], form_data['is_private'])
-        except ActionError:
+        except ActionError as error:
+            self.success_message = ''
+            error_text = error.args[2].split('\n')[0]
             messages.error(
-                self.request,
-                _('An error occurred while creating the repository.'))
-        gitweb.app.update_service_access()
+                self.request, "{0} {1}".format(
+                    _('An error occurred while creating the repository.'),
+                    error_text))
+        else:
+            gitweb.app.update_service_access()
 
         return super().form_valid(form)
 
