@@ -12,11 +12,10 @@ from plinth import cfg, frontpage, menu
 from plinth.daemon import Daemon
 from plinth.modules.firewall.components import Firewall
 from plinth.utils import format_lazy
-from plinth.views import AppView
 
 from .manifest import backup, clients  # noqa, pylint: disable=unused-import
 
-version = 2
+version = 3
 
 managed_services = ['infinoted']
 
@@ -83,11 +82,6 @@ def init():
         app.set_enabled(True)
 
 
-class InfinotedAppView(AppView):
-    app_id = 'infinoted'
-    port_forwarding_info = port_forwarding_info
-
-
 def setup(helper, old_version=None):
     """Install and configure the module."""
     helper.install(managed_packages)
