@@ -5,7 +5,7 @@ URLs for the infinoted module.
 
 from django.conf.urls import url
 
-from plinth.modules.infinoted import InfinotedAppView
+from .views import InfinotedAppView
 
 urlpatterns = [
     url(r'^apps/infinoted/$', InfinotedAppView.as_view(), name='index'),
