@@ -12,6 +12,7 @@ from plinth import cfg, frontpage, menu
 from plinth.daemon import Daemon
 from plinth.modules.firewall.components import Firewall
 from plinth.utils import format_lazy
+from plinth.modules.users.components import UsersAndGroups
 
 from .manifest import backup, clients  # noqa, pylint: disable=unused-import
 
@@ -43,8 +44,6 @@ _description = [
 
 port_forwarding_info = [('UDP', 30000)]
 
-reserved_usernames = ['Debian-minetest']
-
 CONFIG_FILE = '/etc/minetest/minetest.conf'
 AUG_PATH = '/files' + CONFIG_FILE + '/.anon'
 
@@ -87,6 +86,11 @@ class MinetestApp(app_module.App):
                         listen_ports=[(30000, 'udp4')])
         self.add(daemon)
 
+        users_and_groups = UsersAndGroups(
+            'users-and-groups-minetest',
+            reserved_usernames=['Debian-minetest'])
+        self.add(users_and_groups)
+
 
 def init():
     """Initialize the module."""
