@@ -8,9 +8,5 @@ from django.conf.urls import url
 from plinth.views import AppView
 
 urlpatterns = [
-    url(r'^apps/mldonkey/$',
-        AppView.as_view(
-            app_id='mldonkey',
-            show_status_block=True,
-        ), name='index'),
+    url(r'^apps/mldonkey/$', AppView.as_view(app_id='mldonkey'), name='index')
 ]
