@@ -6,10 +6,8 @@ Mumble server configuration form
 from django import forms
 from django.utils.translation import ugettext_lazy as _
 
-from plinth.forms import AppForm
 
-
-class MumbleForm(AppForm):
+class MumbleForm(forms.Form):
     """Mumble server configuration"""
     super_user_password = forms.CharField(
         max_length=20,
@@ -17,7 +15,6 @@ class MumbleForm(AppForm):
         widget=forms.PasswordInput,
         help_text=_(
             'Optional. Leave this field blank to keep the current password. '
-            'SuperUser password can be used to manage permissions in Mumble.'
-        ),
+            'SuperUser password can be used to manage permissions in Mumble.'),
         required=False,
     )
