@@ -153,6 +153,7 @@ class ConnectionForm(forms.Form):
 
 class GenericForm(ConnectionForm):
     """Form to create/edit a generic connection."""
+
     def __init__(self, *args, **kwargs):
         """Initialize the form, populate interface choices."""
         super(GenericForm, self).__init__(*args, **kwargs)
@@ -168,6 +169,7 @@ class GenericForm(ConnectionForm):
 
 class EthernetForm(ConnectionForm):
     """Form to create/edit a ethernet connection."""
+
     def __init__(self, *args, **kwargs):
         """Initialize the form, populate interface choices."""
         super(EthernetForm, self).__init__(*args, **kwargs)
@@ -285,6 +287,48 @@ requires clients to have the password to connect.'),
         return settings
 
 
+class NetworkTopologyForm(forms.Form):
+    """Form to ask the user for network topology.
+
+    That is how the FreedomBox is connected to the internal network topology.
+    Store this information for future suggestions when setting up services.
+
+    """
+    network_topology = forms.ChoiceField(
+        label=format_lazy(
+            _('Specify how your {box_name} is connected to your network'),
+            box_name=cfg.box_name),
+        required=True,
+        widget=forms.RadioSelect,
+        choices=[
+            ('to_router',
+             format_lazy(
+                 _('Connected to a router '
+                   '<p class="help-block">Your {box_name} gets its Internet '
+                   'connection from your router via Wi-Fi or Ethernet cable. '
+                   'This is a typical home setup.</p>'), box_name=cfg.box_name,
+                 allow_markup=True)),
+            ('as_router',
+             format_lazy(
+                 _('{box_name} is your router '
+                   '<p class="help-block">Your {box_name} has multiple '
+                   'network interfaces such as multiple Ethernet ports or '
+                   'a Wi-Fi adapter. {box_name} is directly connected to the '
+                   'Internet and all your devices connect to {box_name} '
+                   'for their Internet connectivity.</p>'),
+                 box_name=cfg.box_name, allow_markup=True)),
+            ('direct',
+             format_lazy(
+                 _('Directly connected to the Internet '
+                   '<p class="help-block">Your Internet connection is '
+                   'directly attached to your {box_name} and there are no '
+                   'other devices on the network. This can happen on '
+                   'community or cloud setups.</p>'), box_name=cfg.box_name,
+                 allow_markup=True)),
+        ],
+    )
+
+
 class InternetConnectionTypeForm(forms.Form):
     """Form for type of public/private IP address ISP provides.
 
@@ -310,7 +354,7 @@ class InternetConnectionTypeForm(forms.Form):
                  allow_markup=True)),
             ('static_public_ip',
              format_lazy(
-                 _('I have a public IP address that does not change overtime '
+                 _('I have a public IP address that does not change over time '
                    '(recommended)'
                    '<p class="help-block">This means that devices on the '
                    'Internet can reach you when you are connected to the '
@@ -334,13 +378,18 @@ class InternetConnectionTypeForm(forms.Form):
                    '{box_name} provides many workaround solutions but each '
                    'solution has some limitations.</p>'),
                  box_name=cfg.box_name, allow_markup=True)),
+            ('unknown',
+             format_lazy(
+                 _('I do not know the type of connection my ISP provides '
+                   '<p class="help-block">You will be suggested the most '
+                   'conservative actions.</p>'), allow_markup=True)),
         ],
         required=True,
         widget=forms.RadioSelect,
     )
 
 
-class RouterConfigurationWizardForm(forms.Form):
+class RouterConfigurationForm(forms.Form):
     """Form to suggest how to configure a router.
 
     Suggest depending on wan connectivity/specific setup. The choice will
