@@ -13,7 +13,7 @@ from plinth.daemon import Daemon
 from plinth.modules.apache.components import diagnose_url
 from plinth.modules.firewall.components import Firewall
 from plinth.utils import format_lazy
-from plinth.views import AppView
+from plinth.modules.users.components import UsersAndGroups
 
 from .manifest import backup  # noqa, pylint: disable=unused-import
 
@@ -40,8 +40,6 @@ _description = [
         box_name=_(cfg.box_name)),
 ]
 
-reserved_usernames = ['privoxy']
-
 app = None
 
 
@@ -79,6 +77,10 @@ class PrivoxyApp(app_module.App):
                         listen_ports=[(8118, 'tcp4'), (8118, 'tcp6')])
         self.add(daemon)
 
+        users_and_groups = UsersAndGroups('users-and-groups-privoxy',
+                                          reserved_usernames=['privoxy'])
+        self.add(users_and_groups)
+
     def diagnose(self):
         """Run diagnostics and return the results."""
         results = super().diagnose()
@@ -104,10 +106,6 @@ def setup(helper, old_version=None):
     helper.call('post', app.enable)
 
 
-class PrivoxyAppView(AppView):
-    app_id = 'privoxy'
-
-
 def diagnose_url_with_proxy():
     """Run a diagnostic on a URL with a proxy."""
     url = 'https://debian.org/'  # Gives a simple redirect to www.
