@@ -1,5 +1,8 @@
 # SPDX-License-Identifier: AGPL-3.0-or-later
 
+from django.contrib import messages
+from django.utils.translation import ugettext_lazy as _
+
 from plinth.modules import quassel
 from plinth.views import AppView
 
@@ -24,5 +27,6 @@ class QuasselAppView(AppView):
             quassel.set_domain(data['domain'])
             quassel.app.get_component(
                 'letsencrypt-quassel').setup_certificates()
+            messages.success(self.request, _('Configuration updated'))
 
         return super().form_valid(form)
