@@ -11,12 +11,13 @@ from plinth import cfg, frontpage, menu
 from plinth.daemon import Daemon
 from plinth.modules.apache.components import Webserver
 from plinth.modules.firewall.components import Firewall
-from plinth.modules.users import register_group
+from plinth.modules.users.components import UsersAndGroups
+from plinth.modules.users import add_user_to_share_group
 from plinth.utils import format_lazy
 
 from .manifest import backup, clients  # noqa, pylint: disable=unused-import
 
-version = 2
+version = 3
 
 managed_services = ['syncthing@syncthing']
 
@@ -34,10 +35,11 @@ _description = [
           'instance of Syncthing that may be used by multiple users.  Each '
           'user\'s set of devices may be synchronized with a distinct set of '
           'folders.  The web interface on {box_name} is only available for '
-          'users belonging to the "admin" group.'), box_name=_(cfg.box_name)),
+          'users belonging to the "admin" or "syncthing" group.'),
+        box_name=_(cfg.box_name)),
 ]
 
-group = ('syncthing', _('Administer Syncthing application'))
+SYSTEM_USER = 'syncthing'
 
 app = None
 
@@ -50,6 +52,9 @@ class SyncthingApp(app_module.App):
     def __init__(self):
         """Create components for the app."""
         super().__init__()
+
+        self.groups = {'syncthing': _('Administer Syncthing application')}
+
         info = app_module.Info(app_id=self.app_id, version=version,
                                name=_('Syncthing'), icon_filename='syncthing',
                                short_description=_('File Synchronization'),
@@ -67,7 +72,7 @@ class SyncthingApp(app_module.App):
                                       icon=info.icon_filename,
                                       url='/syncthing/', clients=info.clients,
                                       login_required=True,
-                                      allowed_groups=[group[0]])
+                                      allowed_groups=list(self.groups))
         self.add(shortcut)
 
         firewall = Firewall('firewall-syncthing-web', info.name,
@@ -85,12 +90,15 @@ class SyncthingApp(app_module.App):
         daemon = Daemon('daemon-syncthing', managed_services[0])
         self.add(daemon)
 
+        users_and_groups = UsersAndGroups(
+            'users-and-groups-syncthing', [SYSTEM_USER], self.groups)
+        self.add(users_and_groups)
+
 
 def init():
     """Initialize the module."""
     global app
     app = SyncthingApp()
-    register_group(group)
 
     setup_helper = globals()['setup_helper']
     if setup_helper.get_state() != 'needs-setup' and app.is_enabled():
@@ -106,3 +114,5 @@ def setup(helper, old_version=None):
 
     if old_version == 1 and app.is_enabled():
         app.get_component('firewall-syncthing-ports').enable()
+
+    add_user_to_share_group(SYSTEM_USER, managed_services[0])
