@@ -14,12 +14,13 @@ from plinth.daemon import Daemon, diagnose_netcat, diagnose_port_listening
 from plinth.modules.apache.components import diagnose_url
 from plinth.modules.firewall.components import Firewall
 from plinth.modules.names.components import DomainType
+from plinth.modules.users.components import UsersAndGroups
 from plinth.signals import domain_added, domain_removed
 
 from . import utils
 from .manifest import backup, clients  # noqa, pylint: disable=unused-import
 
-version = 4
+version = 5
 
 depends = ['names']
 
@@ -38,8 +39,6 @@ _description = [
       'Tor Browser</a>.')
 ]
 
-reserved_usernames = ['debian-tor']
-
 app = None
 
 
@@ -82,6 +81,10 @@ class TorApp(app_module.App):
                           (9040, 'tcp6'), (9053, 'udp4'), (9053, 'udp6')])
         self.add(daemon)
 
+        users_and_groups = UsersAndGroups('users-and-groups-tor',
+                                          reserved_usernames=['debian-tor'])
+        self.add(users_and_groups)
+
     def diagnose(self):
         """Run diagnostics and return the results."""
         results = super().diagnose()
