@@ -4,12 +4,11 @@ FreedomBox app for upgrades.
 """
 
 from django.contrib import messages
-from django.template.response import TemplateResponse
+from django.shortcuts import redirect
 from django.urls import reverse_lazy
 from django.utils.translation import ugettext as _
-from django.views.generic.edit import FormView
 
-from plinth import actions
+from plinth import actions, package
 from plinth.errors import ActionError
 from plinth.modules import upgrades
 from plinth.views import AppView
@@ -23,11 +22,17 @@ class UpgradesConfigurationView(AppView):
     success_url = reverse_lazy('upgrades:index')
     template_name = "upgrades_configure.html"
     app_id = 'upgrades'
-    show_status_block = False
 
     def get_initial(self):
         return {'auto_upgrades_enabled': upgrades.is_enabled()}
 
+    def get_context_data(self, *args, **kwargs):
+        context = super().get_context_data(*args, **kwargs)
+        context['is_busy'] = package.is_package_manager_busy()
+        context['log'] = get_log()
+        context['refresh_page_sec'] = 3 if context['is_busy'] else None
+        return context
+
     def form_valid(self, form):
         """Apply the form changes."""
         old_status = form.initial
@@ -53,19 +58,8 @@ class UpgradesConfigurationView(AppView):
             else:
                 messages.success(self.request,
                                  _('Automatic upgrades disabled'))
-        else:
-            messages.info(self.request, _('Settings unchanged'))
 
-        return FormView.form_valid(self, form)
-
-
-def is_package_manager_busy():
-    """Return whether a package manager is running."""
-    try:
-        actions.superuser_run('packages', ['is-package-manager-busy'])
-        return True
-    except actions.ActionError:
-        return False
+        return super().form_valid(form)
 
 
 def get_log():
@@ -75,18 +69,11 @@ def get_log():
 
 def upgrade(request):
     """Serve the upgrade page."""
-    is_busy = is_package_manager_busy()
-
     if request.method == 'POST':
         try:
             actions.superuser_run('upgrades', ['run'])
             messages.success(request, _('Upgrade process started.'))
-            is_busy = True
         except ActionError:
             messages.error(request, _('Starting upgrade failed.'))
 
-    return TemplateResponse(request, 'upgrades.html', {
-        'title': _('Manual update'),
-        'is_busy': is_busy,
-        'log': get_log()
-    })
+    return redirect(reverse_lazy('upgrades:index'))
