@@ -14,6 +14,8 @@ from plinth import cfg, menu
 from plinth.daemon import Daemon
 from plinth.utils import format_lazy
 
+from .components import UsersAndGroups
+
 version = 3
 
 is_essential = True
@@ -45,9 +47,6 @@ _description = [
         box_name=_(cfg.box_name))
 ]
 
-# All FreedomBox user groups
-groups = dict()
-
 app = None
 
 
@@ -56,6 +55,8 @@ class UsersApp(app_module.App):
 
     app_id = 'users'
 
+    can_be_disabled = False
+
     def __init__(self):
         """Create components for the app."""
         super().__init__()
@@ -73,6 +74,12 @@ class UsersApp(app_module.App):
                         listen_ports=[(389, 'tcp4'), (389, 'tcp6')])
         self.add(daemon)
 
+        # Add the admin group
+        groups = {'admin': _('Access to all services and system settings')}
+        users_and_groups = UsersAndGroups('users-and-groups-admin',
+                                          groups=groups)
+        self.add(users_and_groups)
+
     def diagnose(self):
         """Run diagnostics and return the results."""
         results = super().diagnose()
@@ -127,10 +134,6 @@ def remove_group(group):
     actions.superuser_run('users', options=['remove-group', group])
 
 
-def register_group(group):
-    groups[group[0]] = group[1]
-
-
 def get_last_admin_user():
     """If there is only one admin user return its name else return None."""
     output = actions.superuser_run('users', ['get-group-users', 'admin'])
@@ -152,4 +155,4 @@ def add_user_to_share_group(username, service=None):
         actions.superuser_run(
             'users', ['add-user-to-group', username, 'freedombox-share'])
         if service:
-            actions.superuser_run('service', ['restart', service])
+            actions.superuser_run('service', ['try-restart', service])
