@@ -3,6 +3,7 @@
 Utilities for performing application setup operations.
 """
 
+import importlib
 import logging
 import os
 import threading
@@ -207,7 +208,9 @@ def setup_modules(module_list=None, essential=False, allow_install=True):
 
 def list_dependencies(module_list=None, essential=False):
     """Print list of packages required by selected or essential modules."""
-    for module_name, module in plinth.module_loader.loaded_modules.items():
+    for module_import_path in plinth.module_loader.get_modules_to_load():
+        module_name = module_import_path.split('.')[-1]
+        module = importlib.import_module(module_import_path)
         if essential and not _is_module_essential(module):
             continue
 
@@ -483,18 +486,20 @@ class ForceUpgrader():
             raise self.TemporaryFailure('Package manager is busy')
 
         apps = self._get_list_of_apps_to_force_upgrade()
-        logger.info('Apps needing conffile upgrades: %s',
-                    ', '.join([str(app.name) for app in apps]) or 'None')
+        logger.info(
+            'Apps needing conffile upgrades: %s',
+            ', '.join([str(app.app.info.name) for app in apps]) or 'None')
 
         need_retry = False
         for app, packages in apps.items():
             try:
-                logger.info('Force upgrading app: %s', app.name)
+                logger.info('Force upgrading app: %s', app.app.info.name)
                 if app.force_upgrade(app.setup_helper, packages):
                     logger.info('Successfully force upgraded app: %s',
-                                app.name)
+                                app.app.info.name)
                 else:
-                    logger.info('Ignored force upgrade for app: %s', app.name)
+                    logger.info('Ignored force upgrade for app: %s',
+                                app.app.info.name)
             except Exception as exception:
                 logger.exception('Error running force upgrade: %s', exception)
                 need_retry = True
