@@ -4,13 +4,13 @@ Main FreedomBox views.
 """
 
 import time
+import urllib.parse
 
 from django.contrib import messages
 from django.core.exceptions import ImproperlyConfigured
-from django.http import Http404, HttpResponseRedirect
+from django.http import Http404, HttpResponseBadRequest, HttpResponseRedirect
 from django.template.response import TemplateResponse
 from django.urls import reverse
-from django.utils.http import is_safe_url
 from django.utils.translation import ugettext as _
 from django.views.generic import TemplateView
 from django.views.generic.edit import FormView
@@ -26,11 +26,35 @@ from . import forms, frontpage
 REDIRECT_FIELD_NAME = 'next'
 
 
+def is_safe_url(url):
+    """Check if the URL is safe to redirect to.
+
+    Based on Django internal utility.
+
+    """
+    if url is not None:
+        url = url.strip()
+
+    if not url:
+        return False
+
+    if '\\' in url or url.startswith('///'):
+        return False
+
+    result = urllib.parse.urlparse(url)
+
+    # Only accept URLs to the same site and scheme.
+    if result.scheme or result.netloc:
+        return False
+
+    return True
+
+
 def _get_redirect_url_from_param(request):
     """Return the redirect URL from 'next' GET/POST param."""
     redirect_to = request.GET.get(REDIRECT_FIELD_NAME, '')
     redirect_to = request.POST.get(REDIRECT_FIELD_NAME, redirect_to)
-    if is_safe_url(url=redirect_to, allowed_hosts={request.get_host()}):
+    if is_safe_url(redirect_to):
         return redirect_to
 
     return reverse('index')
@@ -114,11 +138,8 @@ class AppView(FormView):
     retrieve the App instance for the app that is needed for basic information
     and operations such as enabling/disabling the app.
 
-    'form_class' is the Django form class that is used by this view. By default
-    the AppForm class is used.
-
-    'show_status_block' is a boolean to determine if the status section must be
-    shown in this app's page.
+    'form_class' is the Django form class that is used by this view. It may be
+    None if the app does not have a configuration form. Default is None.
 
     'template_name' is the template used to render this view. By default it is
     app.html. It may be overridden with a template that derives from app.html
@@ -130,11 +151,7 @@ class AppView(FormView):
     forward ports on their router for this app to work properly.
 
     """
-    form_class = forms.AppForm
-    # Display the 'status' block of the app.html template
-    # This block uses information from service.is_running. This method is
-    # optional, so allow not showing this block here.
-    show_status_block = True
+    form_class = None
     app_id = None
     template_name = 'app.html'
     port_forwarding_info = None
@@ -144,6 +161,17 @@ class AppView(FormView):
         super().__init__(*args, **kwargs)
         self._common_status = None
 
+    def post(self, request, *args, **kwargs):
+        """Handle app enable/disable button separately."""
+        if 'app_enable_disable_button' not in request.POST:
+            return super().post(request, *args, **kwargs)
+
+        form = forms.AppEnableDisableForm(data=self.request.POST)
+        if form.is_valid():
+            return self.enable_disable_form_valid(form)
+
+        return HttpResponseBadRequest('Invalid form submission')
+
     @property
     def success_url(self):
         return self.request.path
@@ -156,6 +184,17 @@ class AppView(FormView):
 
         return app.App.get(self.app_id)
 
+    def get_form(self, *args, **kwargs):
+        """Return an instance of this view's form.
+
+        Also the form_class for this view to be None.
+
+        """
+        if not self.form_class:
+            return None
+
+        return super().get_form(*args, **kwargs)
+
     def _get_common_status(self):
         """Return the status needed for form and template.
 
@@ -171,39 +210,52 @@ class AppView(FormView):
 
     def get_initial(self):
         """Return the status of the app to fill in the form."""
-        return self._get_common_status()
+        initial = super().get_initial()
+        initial.update(self._get_common_status())
+        return initial
 
     def form_valid(self, form):
         """Enable/disable a service and set messages."""
-        old_status = form.initial
-        new_status = form.cleaned_data
-
-        if old_status['is_enabled'] == new_status['is_enabled']:
-            # TODO: find a more reliable/official way to check whether the
-            # request has messages attached.
-            if not self.request._messages._queued_messages:
-                messages.info(self.request, _('Setting unchanged'))
-        else:
-            if new_status['is_enabled']:
-                self.app.enable()
-                messages.success(self.request, _('Application enabled'))
-            else:
-                self.app.disable()
-                messages.success(self.request, _('Application disabled'))
+        if not self.request._messages._queued_messages:
+            messages.info(self.request, _('Setting unchanged'))
 
         return super().form_valid(form)
 
+    def get_enable_disable_form(self):
+        """Return an instance of the app enable/disable form.
+
+        If the app can't be disabled by the user, return None.
+
+        """
+        if not self.app.can_be_disabled:
+            return None
+
+        initial = {
+            'should_enable': not self._get_common_status()['is_enabled']
+        }
+        return forms.AppEnableDisableForm(initial=initial)
+
+    def enable_disable_form_valid(self, form):
+        """Form handling for enabling / disabling apps."""
+        should_enable = form.cleaned_data['should_enable']
+        if should_enable != self.app.is_enabled():
+            if should_enable:
+                self.app.enable()
+            else:
+                self.app.disable()
+
+        return HttpResponseRedirect(self.request.path)
+
     def get_context_data(self, *args, **kwargs):
         """Add service to the context data."""
         context = super().get_context_data(*args, **kwargs)
         context.update(self._get_common_status())
-        context['app'] = self.app  # XXX: Remove this for template security
         context['app_id'] = self.app.app_id
         context['is_running'] = app_is_running(self.app)
         context['app_info'] = self.app.info
         context['has_diagnostics'] = self.app.has_diagnostics()
-        context['show_status_block'] = self.show_status_block
         context['port_forwarding_info'] = self.port_forwarding_info
+        context['app_enable_disable_form'] = self.get_enable_disable_form()
 
         from plinth.modules.firewall.components import Firewall
         context['firewall'] = self.app.get_components_of_type(Firewall)
@@ -231,6 +283,12 @@ class SetupView(TemplateView):
             context[
                 'package_manager_is_busy'] = package.is_package_manager_busy()
 
+        context['refresh_page_sec'] = None
+        if context['setup_state'] == 'up-to-date':
+            context['refresh_page_sec'] = 0
+        elif context['setup_current_operation']:
+            context['refresh_page_sec'] = 3
+
         return context
 
     def dispatch(self, request, *args, **kwargs):
